<?php

$lan = array(
  'existingusers' => "Usuarios existentes",
  'nonexistingusers' => "No hay ning&uacute;n usuario",
  'existcheckintro' => 'P&aacute;gina para comprobar la presencia de usuarios en la base de datos',
  'whatistype' => '&#191;Cu&aacute;l es el tipo de informaci&oacute;n que quiere comprobar?',
  "foreignkey" => "Clave externa",
  "email" => "Email",
  "continue" => "Continuar",
  "pastevalues" => "Copie los valores que quiera comprobar en este
  recuadro, uno por l&iacute;nea",
);

?>
